==> AGXUnreal-1.17.0_UE-5.4_Linux.zip: Marketplace/AGXUnreal/Source/ThirdParty/agx/include/openplx/Physics3D/Interactions/Toughness/DefaultLockToughness.h <==
#pragma once
#include <openplx/Object.h>
#include <openplx/ExpressionEvaluator.h>
#include <memory>
#include <stdexcept>
#include <unordered_map>
#include <openplx/Physics3D/Physics3DForward.h>
#include <openplx/Math/MathForward.h>
#include <openplx/Physics/PhysicsForward.h>
#include <openplx/Physics3D/Interactions/Toughness/DefaultMateToughness.h>
#include <openplx/Physics/Interactions/Toughness/DefaultToughness.h>
/* Generated code for model DefaultLockToughness */
namespace openplx::Physics3D::Interactions::Toughness {
    /**
     *     Defines one toughness model for each constrained degree of freedom for a Lock
     *     */
    class DefaultLockToughness : public openplx::Physics3D::Interactions::Toughness::DefaultMateToughness {
        protected:
            std::shared_ptr<openplx::Physics::Interactions::Toughness::DefaultToughness> m_along_main;
            std::shared_ptr<openplx::Physics::Interactions::Toughness::DefaultToughness> m_along_normal;
            std::shared_ptr<openplx::Physics::Interactions::Toughness::DefaultToughness> m_along_cross;
            std::shared_ptr<openplx::Physics::Interactions::Toughness::DefaultToughness> m_around_main;
            std::shared_ptr<openplx::Physics::Interactions::Toughness::DefaultToughness> m_around_normal;
            std::shared_ptr<openplx::Physics::Interactions::Toughness::DefaultToughness> m_around_cross;

        public:
            DefaultLockToughness();
            std::shared_ptr<openplx::Physics::Interactions::Toughness::DefaultToughness> along_main() const;
            std::shared_ptr<openplx::Physics::Interactions::Toughness::DefaultToughness> along_normal() const;
            std::shared_ptr<openplx::Physics::Interactions::Toughness::DefaultToughness> along_cross() const;
            std::shared_ptr<openplx::Physics::Interactions::Toughness::DefaultToughness> around_main() const;
            std::shared_ptr<openplx::Physics::Interactions::Toughness::DefaultToughness> around_normal() const;
            std::shared_ptr<openplx::Physics::Interactions::Toughness::DefaultToughness> around_cross() const;
            void setDynamic(const std::string& key, openplx::Core::Any&& value) override;
            openplx::Core::Any getDynamic(const std::string& key) const override;
            openplx::Core::Any callDynamic(const std::string& key, const std::vector<openplx::Core::Any>& args) override;
            void extractObjectFieldsTo(std::vector<std::shared_ptr<openplx::Core::Object>>& output) const override;
            void extractEntriesTo(std::vector<std::pair<std::string, openplx::Core::Any>>& output) const override;
            void triggerOnInit(const openplx::RuntimeContext& context) override;
    };
}

==> AGXUnreal-2.0.0_UE-5.5_Linux.zip: Marketplace/AGXUnreal/Source/ThirdParty/agx/include/openplx/Physics3D/Interactions/Toughness/DefaultLockToughness.h <==
#pragma once
#include <openplx/Object.h>
#include <openplx/ExpressionEvaluator.h>
#include <memory>
#include <stdexcept>
#include <unordered_map>
#include <openplx/Physics3D/Physics3DBundleExport.h>
#include <openplx/Physics3D/Physics3DForward.h>
#include <openplx/Math/MathForward.h>
#include <openplx/Physics/PhysicsForward.h>
#include <openplx/Physics3D/Interactions/Toughness/DefaultMateToughness.h>
#include <openplx/Physics/Interactions/Toughness/DefaultToughness.h>

#ifdef _MSC_VER
#  pragma warning(push)
#  pragma warning(disable: 4251)
#endif

/* Generated code for model DefaultLockToughness */
namespace openplx::Physics3D::Interactions::Toughness {
    /**
     *     Defines one toughness model for each constrained degree of freedom for a Lock
     *     */
    class OPENPLX_Physics3D_BUNDLE_EXPORT DefaultLockToughness : public openplx::Physics3D::Interactions::Toughness::DefaultMateToughness {
        protected:
            std::shared_ptr<openplx::Physics::Interactions::Toughness::DefaultToughness> m_along_main;
            std::shared_ptr<openplx::Physics::Interactions::Toughness::DefaultToughness> m_along_normal;
            std::shared_ptr<openplx::Physics::Interactions::Toughness::DefaultToughness> m_along_cross;
            std::shared_ptr<openplx::Physics::Interactions::Toughness::DefaultToughness> m_around_main;
            std::shared_ptr<openplx::Physics::Interactions::Toughness::DefaultToughness> m_around_normal;
            std::shared_ptr<openplx::Physics::Interactions::Toughness::DefaultToughness> m_around_cross;

        public:
            DefaultLockToughness();
            virtual ~DefaultLockToughness();
            std::shared_ptr<openplx::Physics::Interactions::Toughness::DefaultToughness> along_main() const;
            std::shared_ptr<openplx::Physics::Interactions::Toughness::DefaultToughness> along_normal() const;
            std::shared_ptr<openplx::Physics::Interactions::Toughness::DefaultToughness> along_cross() const;
            std::shared_ptr<openplx::Physics::Interactions::Toughness::DefaultToughness> around_main() const;
            std::shared_ptr<openplx::Physics::Interactions::Toughness::DefaultToughness> around_normal() const;
            std::shared_ptr<openplx::Physics::Interactions::Toughness::DefaultToughness> around_cross() const;
            void setDynamic(const std::string& key, openplx::Core::Any&& value) override;
            openplx::Core::Any getDynamic(const std::string& key) const override;
            openplx::Core::Any callDynamic(const std::string& key, const std::vector<openplx::Core::Any>& args) override;
            void extractObjectFieldsTo(std::vector<std::shared_ptr<openplx::Core::Object>>& output) const override;
            void extractEntriesTo(std::vector<std::pair<std::string, openplx::Core::Any>>& output) const override;
            void triggerOnInit(const openplx::RuntimeContext& context) override;
    };
}

#ifdef _MSC_VER
#  pragma warning(pop)
#endif
